@@ -33,29 +33,6 @@ class TimeDistributed(nn.Module):
         return y
 
 
-class TimeDistributedEmbeddingBag(nn.EmbeddingBag):
-    def __init__(self, *args, batch_first: bool = False, **kwargs):
-        super().__init__(*args, **kwargs)
-        self.batch_first = batch_first
-
-    def forward(self, x):
-
-        if len(x.size()) <= 2:
-            return self.forward(x)
-
-        # Squash samples and timesteps into a single axis
-        x_reshape = x.contiguous().view(-1, x.size(-1))  # (samples * timesteps, input_size)
-
-        y = super().forward(x_reshape)
-
-        # We have to reshape Y
-        if self.batch_first:
-            y = y.contiguous().view(x.size(0), -1, y.size(-1))  # (samples, timesteps, output_size)
-        else:
-            y = y.view(-1, x.size(1), y.size(-1))  # (timesteps, samples, output_size)
-        return y
-
-
 class TimeDistributedInterpolation(nn.Module):
     def __init__(self, output_size: int, batch_first: bool = False, trainable: bool = False):
         super().__init__()
@@ -110,7 +87,7 @@ class GatedLinearUnit(nn.Module):
         for n, p in self.named_parameters():
             if "bias" in n:
                 torch.nn.init.zeros_(p)
-            elif "fc2" in n:
+            elif "fc" in n:
                 torch.nn.init.xavier_uniform_(p)
 
     def forward(self, x):
@@ -351,7 +328,7 @@ class VariableSelectionNetwork(nn.Module):
                     variable_embedding = self.prescalers[name](variable_embedding)
                 weight_inputs.append(variable_embedding)
                 var_outputs.append(self.single_variable_grns[name](variable_embedding))
-            var_outputs = torch.stack(var_outputs, axis=-1)
+            var_outputs = torch.stack(var_outputs, dim=-1)
 
             # calculate variable weights
             flat_embedding = torch.cat(weight_inputs, dim=-1)
@@ -359,7 +336,7 @@ class VariableSelectionNetwork(nn.Module):
             sparse_weights = self.softmax(sparse_weights).unsqueeze(-2)
 
             outputs = var_outputs * sparse_weights
-            outputs = outputs.sum(axis=-1)
+            outputs = outputs.sum(dim=-1)
         else:  # for one input, do not perform variable selection but just encoding
             name = next(iter(self.single_variable_grns.keys()))
             variable_embedding = x[name]
@@ -431,9 +408,9 @@ class InterpretableMultiHeadAttention(nn.Module):
         self.d_k = self.d_q = self.d_v = d_model // n_head
         self.dropout = nn.Dropout(p=dropout)
 
-        self.v_layer = nn.Linear(self.d_model, self.d_v, bias=False)
-        self.q_layers = nn.ModuleList([nn.Linear(self.d_model, self.d_q, bias=False) for _ in range(self.n_head)])
-        self.k_layers = nn.ModuleList([nn.Linear(self.d_model, self.d_k, bias=False) for _ in range(self.n_head)])
+        self.v_layer = nn.Linear(self.d_model, self.d_v)
+        self.q_layers = nn.ModuleList([nn.Linear(self.d_model, self.d_q) for _ in range(self.n_head)])
+        self.k_layers = nn.ModuleList([nn.Linear(self.d_model, self.d_k) for _ in range(self.n_head)])
         self.attention = ScaledDotProductAttention()
         self.w_h = nn.Linear(self.d_v, self.d_model, bias=False)
 
